Customized Applications of *pyDeltaRCM*
=======================================

Below is a "model zoo" containing a list with links to customized subclasses
of the *pyDeltaRCM* found "in the wild". If you have a implemented a custom
subclass of the model and would like us to highlight it here please reach out
or open a pull request!


VegetationModel
---------------

This implementation of the *pyDeltaRCM* model is based off of the "DeltaRCM
Vegetation" model presented in `Lauzon and Murray (2018) <https://doi.org/10.1029/2018GL079405>`_.

Link: `VegetationModel <https://github.com/amoodie/Vegetation_pyDeltaRCM>`_


Faulting Models
---------------

This implementation of the *pyDeltaRCM* model is used in the paper
`Moodie and Passalacqua (2021) <https://doi.org/10.1029/2021GL095053>`_ to
simulate a deltas with faulting scaled to the Mississippi River delta and the Selenga River delta.

Link: `MississippiFaultsModel <https://github.com/amoodie/paper_resources/blob/main/Moodie_faultingsubsidence/model/scripts/mississippi_faults.py>`_

Link: `SelengaModel <https://github.com/amoodie/paper_resources/blob/main/Moodie_faultingsubsidence/model/scripts/selenga_faults.py>`_


VariableSLRModel
----------------

This implementation of the *pyDeltaRCM* model is used in the paper
`Hariharan et al (2022) <https://doi.org/10.1029/2022JF006762>`_ to simulate
variable sea level rise scenarios.

Link: `VariableSLRModel <https://github.com/elbeejay/variableSLR_pyDeltaRCM>`_


CrateringModel
--------------

This implementation of the *pyDeltaRCM* model is used in the paper
`Moodie and Goudge (2025) <https://doi.org/10.1029/2023JE008183>`_ to simulate
interaction of fluvial-deltaic processes and crater formation/preservation.

Link: `CraterModel <https://github.com/amoodie/paper_resources/blob/main/Moodie_marscraterreworking/model/CraterModel.py>`_
